#########
DATParser
#########

The DATParser parses .dat files (either from Redump or No-Intro) to pull out useful information about ROM files.

For Redump, ROMSearch can automatically download the latest .dat file from their site. This is not possible for
No-Intro, so users will have to download this file manually.

For more details on the DATParser arguments, see the :doc:`config file documentation <../configs/config>`.

API
===

.. autoclass:: romsearch.DATParser
    :no-index:
    :members:
    :undoc-members: